Skip to content

Evaluates expr while redrawing the progress bar for every progress bar update. This function is meant to be used in test cases, when specifically testing the progress bar output.

Usage

cli_with_progress_ticks(expr)

Arguments

expr

Expression to evaluate.

Value

The value of expr.