version#

Manage software versions according to LIBRA’S Versioning paradigm. To use:

  • Projects must have a valid CMake cache.

  • Projects must use libra_extract_version().

To use:

clibra build --preset debug  # configure and build
clibra version               # show numeric version
clibra version --full        # show full version
clibra version --bump        # Bump version
clibra version --check 1.23  # CI gate: fail if resolve != 1.2.3

Requires LIBRA_PROJECT_VERSION, LIBRA_PROJECT_VERSION_NUMERIC, LIBRA_PROJECT_VERSION_PRERELEASE to be set, which are set by libra_extract_version().

CMake equivalent#

This command has no CMake equivalent.

Flag reference#

clibra version#

Version management

Usage: clibra version [OPTIONS]

Options:#

  • -c, --check <CHECK> — Compare the resolved version against a specified one, for use in CI gating. Can be used in conjunction with –bump

  • --full — Use/parse/manage full versions instead of numeric versions

  • -o, --output <OUTPUT> — The output format to print the version in

    Possible values: human, json

  • -b, --bump — Bump the patch component of the resolved version (numeric only)