Evaluate an expression with forcing all progress bar updates enabled
Source:R/timer.R
cli_with_progress_ticks.RdEvaluates expr while redrawing the progress bar for every progress
bar update. This function is meant to be used in test cases, when
specifically testing the progress bar output.