docs#

Configure (if needed) and build project documentation.

clibra docs --preset docs

Requires LIBRA_DOCS to be ON in the preset’s CMake cache. clibra docs attempts to build both the apidoc and sphinxdoc targets independently. If either target is listed as unavailable by the build system, it is skipped with a warning rather than an error — so a project with only Doxygen (no Sphinx) or only Sphinx (no Doxygen) works without any special configuration.

CMake equivalent#

cmake --build --preset <n> --target apidoc     # Doxygen API docs
cmake --build --preset <n> --target sphinxdoc  # Sphinx docs

For documentation tool configuration, see Documentation.

Flag reference#

clibra docs#

Configure (if needed) and build/check documentation.

Requires LIBRA_DOCS=ON in the preset’s CMake cache. The preset defaults to docs if not given.

Attempts to build both apidoc and sphinxdoc targets independently. If a target is listed as unavailable by the build system, it is skipped with a warning rather than an error. Has suboptions for checking documentation.

Usage: clibra docs [OPTIONS]

Options:#

  • -D <VAR=VALUE>

  • -r, --reconfigure — Force the configure step even if the build directory exists

  • -f, --fresh — Reconfigure with a –fresh cmake build directory

  • -c, --check <CHECK> — The check to run. Defaults to nothing

    Possible values: clang, doxygen

  • -k, --keep-going — Continue building after errors. Only valid with {Ninja, Unix Makefiles} generators